@@ -1,9 +1,9 @@
 /* 
  * gnome-print-pango.c
  *
- * Copyright (C) 2003
+ * Copyright (C) 2003-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,13 +21,49 @@
  * Boston, MA  02111-1307, USA.
  */
 
-#include "gnome-print-pango.h"
+#include "config.h"
 #define GTK_TEXT_USE_INTERNAL_UNSUPPORTED_API
 #include <gtk/gtktextlayout.h>
+#include "gnome-print-pango.h"
 
-#define SLANT_SLOPE 0.15
+#ifdef GP_HAS_PANGO
+#	include <libgnomeprint/gnome-print-pango.h>
+#	define TEXT_ZOOM_FACTOR	(4. / 3.)
 
-void gnome_print_pango_layout_print (GnomePrintContext *gpc, PangoLayout* pl) {
+void pango_layout_print (GnomePrintContext *gpc, PangoLayout* pl)
+{
+	PangoAttrList *attrs = pango_layout_get_attributes (pl);
+	PangoLayout *layout = (PangoLayout*) gnome_print_pango_create_layout (gpc);
+	const char *text = pango_layout_get_text (pl);
+	int w1, w2, h1, h2, l;
+	double zoom, extra_space;
+	l = strlen (text);
+	pango_layout_set_text (layout, text, l);
+	pango_layout_set_attributes (layout, attrs);
+	pango_layout_get_size (pl, &w1, &h1);
+	pango_layout_get_size (layout, &w2, &h2);
+	zoom = (double) h1 / (double) h2;
+	extra_space = w1 / zoom - w2;
+	if (l > 1) {
+		PangoAttribute *pa;
+		PangoAttrList *pal = pango_attr_list_copy (attrs);
+		pa = pango_attr_letter_spacing_new ((int) extra_space / l);
+		pa->start_index = 0;
+		pa->end_index = l;
+		pango_attr_list_insert (pal, pa);
+		pango_layout_set_attributes (layout, pal);
+	}
+	gnome_print_gsave (gpc);
+	gnome_print_scale (gpc, zoom, -zoom); /* not so good. Why is zoom necessary to get the same size ? Have a look at resolution */
+	gnome_print_moveto (gpc, 0., 0.);
+	gnome_print_pango_layout (gpc, layout);
+	gnome_print_grestore (gpc);
+	g_object_unref (layout);
+}
+
+#else
+
+void gpc_print_pango_layout_print (GnomePrintContext *gpc, PangoLayout* pl) {
 	gint i, top, bottom;
 	GnomeFont *font;
 	GnomeFontFace *face;
@@ -35,7 +71,8 @@ void gnome_print_pango_layout_print (GnomePrintContext *gpc, PangoLayout* pl) {
 	GSList *extra_attrs_list;
 	PangoFontDescription *desc;
 	PangoGlyphItem *item;
-	PangoRectangle logical_rect, ink_rect;
+	PangoRectangle logical_rect, ink_rect, rect;
+	PangoLayout *layout;
 	ArtDRect art_rect;
 	const char *text = pango_layout_get_text (pl);
 	gboolean foreground_set;
@@ -49,6 +86,7 @@ void gnome_print_pango_layout_print (GnomePrintContext *gpc, PangoLayout* pl) {
 	GtkTextAppearance* appearance;
 	int underline_type;
 	PangoAlignment align = pango_layout_get_alignment (pl);
+	double zoom;
 	
 	pango_layout_get_extents (pl, NULL, &logical_rect);
 	gnome_print_gsave (gpc);
@@ -82,6 +120,7 @@ void gnome_print_pango_layout_print (GnomePrintContext *gpc, PangoLayout* pl) {
 		glyph_list = gnome_glyphlist_new ();
 		extra_attrs_list = item->item->analysis.extra_attrs;
 		top = pango_layout_iter_get_baseline(iter) / PANGO_SCALE;
+		pango_layout_iter_get_char_extents (iter, &logical_rect);
 		bottom = 0;
 		while (extra_attrs_list)
 		{
@@ -127,6 +166,11 @@ void gnome_print_pango_layout_print (GnomePrintContext *gpc, PangoLayout* pl) {
 			extra_attrs_list = extra_attrs_list->next;
 		}
 		pango_layout_iter_get_run_extents (iter, &ink_rect, &logical_rect);
+		layout = pango_layout_new (pango_layout_get_context (pl));
+		pango_layout_set_font_description (layout, desc);
+		pango_layout_set_text (layout, text + item->item->offset, item->item->length);
+		pango_layout_get_extents (layout, &rect, NULL);
+		g_object_unref (layout);
 		if (background_set)
 		{
 			gnome_print_setrgbcolor (gpc, (float) background_red / 0xFFFF,
@@ -185,9 +229,10 @@ void gnome_print_pango_layout_print (GnomePrintContext *gpc, PangoLayout* pl) {
 		}
 		gnome_glyphlist_bbox (glyph_list, scale, 0, &art_rect);
 		slant = (pango_font_description_get_style (desc) != PANGO_STYLE_NORMAL) && !gnome_font_face_is_italic (face);
+		zoom = ((double) ink_rect.height) / PANGO_SCALE / (art_rect.y1 - art_rect.y0);
 		if (item->glyphs->num_glyphs > 1) {
-			space = (((double) ink_rect.width / PANGO_SCALE - art_rect.x1 + art_rect.x0) - (slant)? top * SLANT_SLOPE: 0.)
-						/ (item->glyphs->num_glyphs - 1);
+			space = (((double) ink_rect.width / PANGO_SCALE / zoom - art_rect.x1 + art_rect.x0) - ((slant)? top * 0.15 / zoom: 0.))
+						/ item->glyphs->num_glyphs;
 			gnome_glyphlist_unref (glyph_list);
 			glyph_list = gnome_glyphlist_new ();
 			gnome_print_moveto (gpc, logical_rect.x / PANGO_SCALE,
@@ -203,11 +248,11 @@ void gnome_print_pango_layout_print (GnomePrintContext *gpc, PangoLayout* pl) {
 		if (slant) {
 		/*simulate slanted font*/
 			double matrix [6] = {
-				 1.,
-				0., SLANT_SLOPE, -1., .0, .0};
+				 zoom,
+				0., .15 * zoom, -zoom, .0, .0};
 			gnome_print_concat (gpc, matrix);
 		} else
-			gnome_print_scale(gpc, 1., -1.);
+			gnome_print_scale(gpc, zoom, -zoom);
 		gnome_print_glyphlist (gpc, glyph_list);
 		gnome_print_grestore(gpc);
 		gnome_glyphlist_unref (glyph_list);
@@ -215,3 +260,4 @@ void gnome_print_pango_layout_print (GnomePrintContext *gpc, PangoLayout* pl) {
 	pango_layout_iter_free (iter);
 	gnome_print_grestore (gpc);
 }
+#endif
