@@ -68,6 +68,7 @@ bool gcpArrow::Save(xmlDocPtr xml, xmlNodePtr node)
 bool gcpArrow::Load(xmlNodePtr node)
 {
 	char* tmp, *endptr;
+	bool result;
 	xmlNodePtr child;
 	tmp = (char*)xmlGetProp(node, (xmlChar*)"id");
 	if (tmp)
@@ -80,25 +81,29 @@ bool gcpArrow::Load(xmlNodePtr node)
 	tmp = (char*)xmlGetProp(child, (xmlChar*)"x");
 	if (!tmp) return false;
 	m_x = strtod(tmp, &endptr);
+	result = *endptr;
 	xmlFree(tmp);
-	if (*endptr) return false;
+	if (result) return false;
 	tmp = (char*)xmlGetProp(child, (xmlChar*)"y");
 	if (!tmp) return false;
 	m_y = strtod(tmp, &endptr);
+	result = *endptr;
 	xmlFree(tmp);
-	if (*endptr) return false;
+	if (result) return false;
 	child = GetNodeByName(node, "end");
 	if (!child) return false;
 	tmp = (char*)xmlGetProp(child, (xmlChar*)"x");
 	if (!tmp) return false;
-	xmlFree(tmp);
 	m_width = strtod(tmp, &endptr) - m_x;
-	if (*endptr) return false;
+	result = *endptr;
+	xmlFree(tmp);
+	if (result) return false;
 	tmp = (char*)xmlGetProp(child, (xmlChar*)"y");
 	if (!tmp) return false;
 	m_height = strtod(tmp, &endptr) - m_y;
+	result = *endptr;
 	xmlFree(tmp);
-	if (*endptr) return false;
+	if (result) return false;
 	return true;
 }
 
