@@ -50,7 +50,12 @@
 using namespace OpenBabel;
 using namespace std;
 
+
+#ifdef GCU_OLD_VER
 gcpDocument::gcpDocument(): Object(DocumentType)
+#else
+gcpDocument::gcpDocument(): Document ()
+#endif
 {
 	m_pView = NULL;
 	m_filename = NULL;
@@ -233,6 +238,8 @@ bool gcpDocument::ImportOB(OBMol& Mol)
 		}
 	}
 	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
+	m_pView->Update (this);
+	m_pView->EnsureSize ();
 	return true;
 }
 
@@ -474,39 +481,61 @@ bool gcpDocument::Load(xmlNodePtr root)
 	char* tmp;
 	Object* pObject;
 	tmp = (char*)xmlGetProp(root, (xmlChar*)"id");
-	if (tmp) SetId(tmp);
+	if (tmp)
+	{
+		SetId(tmp);
+		xmlFree(tmp);
+	}
 	tmp = (char*)xmlGetProp(root, (xmlChar*)"creation");
 	if (tmp)
 	{
 		g_date_set_parse(&CreationDate, tmp);
 		if (!g_date_valid(&CreationDate)) g_date_clear(&CreationDate, 1);
+		xmlFree(tmp);
 	}
 	tmp = (char*)xmlGetProp(root, (xmlChar*)"revision");
 	if (tmp)
 	{
 		g_date_set_parse(&RevisionDate, tmp);
 		if (!g_date_valid(&RevisionDate)) g_date_clear(&RevisionDate, 1);
+		xmlFree(tmp);
 	}
 
 	node = GetNodeByName(root, "title");
 	if (node)
 	{
 		tmp = (char*)xmlNodeGetContent(node);
-		if (tmp) m_title = g_strdup(tmp);
+		if (tmp)
+		{
+			m_title = g_strdup(tmp);
+			xmlFree(tmp);
+		}
 	}
 	node = GetNodeByName(root, "author");
 	if (node)
 	{
 		tmp = (char*)xmlGetProp(node, (xmlChar*)"name");
-		if (tmp) m_author = g_strdup(tmp);
+		if (tmp)
+		{
+			m_author = g_strdup(tmp);
+			xmlFree(tmp);
+		}
 		tmp = (char*)xmlGetProp(node, (xmlChar*)"e-mail");
-		if (tmp) m_mail = g_strdup(tmp);
+		if (tmp)
+		{
+			m_mail = g_strdup(tmp);
+			xmlFree(tmp);
+		}
 	}
 	node = GetNodeByName(root, "comment");
 	if (node)
 	{
 		tmp = (char*)xmlNodeGetContent(node);
-		if (tmp) m_comment = g_strdup(tmp);
+		if (tmp)
+		{
+			m_comment = g_strdup(tmp);
+			xmlFree(tmp);
+		}
 	}
 
 	m_bIsLoading = true;
@@ -545,12 +574,14 @@ bool gcpDocument::Load(xmlNodePtr root)
 	}
 	m_bIsLoading = false;
 	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
+	m_pView->EnsureSize ();
 	return true;
 }
 	
 void gcpDocument::ParseXMLTree(xmlDocPtr xml)
 {
 	Load(xml->children);
+	g_signal_emit_by_name (GetWidget (), "update_bounds");
 }
 
 xmlDocPtr gcpDocument::BuildXMLTree()
@@ -899,6 +930,7 @@ void gcpDocument::SetActive()
 {
 	ActivateMenu(EditMenu, UndoMenu, !m_UndoList.empty());
 	ActivateMenu(EditMenu, RedoMenu, !m_RedoList.empty());
+	ActivateMenu(EditMenu, SaveAsImageMenu, HasChildren ());
 }
 
 extern xmlDocPtr pXmlDoc;
@@ -976,7 +1008,7 @@ void gcpDocument::AddData(xmlNodePtr node)
 		str = (const char*)child->name;
 		pObject = Object::CreateObject(str, this);
 		AddObject(pObject);
-		pObject->Load(child); 
+		pObject->Load(child);
 		m_pView->Update(pObject);//FIXME: should not be necessary, but solve problem with cyclic double bonds
 		pData->SetSelected(pObject);
 		node = node->next;
