@@ -35,6 +35,7 @@
 #undef VERSION
 #include "config.h"
 #include "file.h"
+#include "globals.h"
 #include <libgnomeui/libgnomeui.h>
 #include <libxml/parser.h>
 #include <libxml/parserInternals.h>
@@ -61,6 +62,7 @@ bool file_process(const gchar* filename, int filetype, bool bSave, gcpDocument *
 	{
 		GtkWidget* message = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
 															_("Please enter a file name,\nnot a directory"));
+		SET_ICON(message);
 		g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
 		gtk_widget_show(message);
 		return true;
@@ -128,6 +130,7 @@ bool file_process(const gchar* filename, int filetype, bool bSave, gcpDocument *
 		{
 			gchar * message = g_strdup_printf(_("File %s\nexists, overwrite?"), filename2);
 			GtkDialog* Box = GTK_DIALOG(gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
+			SET_ICON(Box);
 			result = gtk_dialog_run(Box);
 			gtk_widget_destroy(GTK_WIDGET(Box));
 			g_free(message);
@@ -256,6 +259,7 @@ void do_open_gcp(const gchar* filename, gcpDocument* pDoc)
 			break;
 		}
 		message = gtk_message_dialog_new(NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
+		SET_ICON(message);
 		g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
 		gtk_widget_show(message);
 		g_free(mess);
@@ -321,6 +325,7 @@ void do_open_with_babel(const gchar* filename, const gchar* ext, gcpDocument* pD
 			break;
 		}
 		message = gtk_message_dialog_new(NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
+		SET_ICON(message);
 		g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
 		gtk_widget_show(message);
 		g_free(mess);
