@@ -806,6 +806,54 @@ void gcpView::ExportImage (const char* filename, const char* type)
 		remove (tmpname);
 		g_free (tmpname);
 		g_free (command_line);
+	} else if (!strcmp (type, "svg")) {
+		xmlDocPtr doc = xmlNewDoc ((const xmlChar*)"1.0");
+		char *old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
+		char *buf;
+		setlocale (LC_NUMERIC, "C");
+		xmlNewDtd (doc,
+			   (const xmlChar*)"svg", (const xmlChar*)"-//W3C//DTD SVG 1.1//EN",
+			   (const xmlChar*)"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd");
+		doc->children = xmlNewDocNode (doc, NULL, (const xmlChar*)"svg", NULL);
+		xmlNsPtr ns = xmlNewNs (doc->children, (const xmlChar*)"http://www.w3.org/2000/svg", NULL);
+		xmlSetNs (doc->children, ns);
+		xmlNewProp (doc->children, (const xmlChar*)"version", (const xmlChar*)"1.1");
+		rect.x0 = floor (rect.x0);
+		rect.y0 = floor (rect.y0);
+		rect.x1 = ceil (rect.x1);
+		rect.y1 = ceil (rect.y1);
+		buf = g_strdup_printf ("%g", rect.x1 - rect.x0);
+		xmlNewProp (doc->children, (const xmlChar*)"width", (const xmlChar*)buf);
+		g_free (buf);
+		buf = g_strdup_printf ("%g", rect.y1 - rect.y0);
+		xmlNewProp (doc->children, (const xmlChar*)"height", (const xmlChar*)buf);
+		g_free (buf);
+		xmlNodePtr node;
+		node = xmlNewDocNode (doc, NULL, (const xmlChar*)"rect", NULL);
+		xmlAddChild (doc->children, node);
+		buf = g_strdup_printf ("%g", rect.x1 - rect.x0);
+		xmlNewProp (node, (const xmlChar*)"width", (const xmlChar*)buf);
+		g_free (buf);
+		buf = g_strdup_printf ("%g", rect.y1 - rect.y0);
+		xmlNewProp (node, (const xmlChar*)"height", (const xmlChar*)buf);
+		g_free (buf);
+		xmlNewProp (node, (const xmlChar*)"stroke", (const xmlChar*)"none");
+		xmlNewProp (node, (const xmlChar*)"fill", (const xmlChar*)"white");
+		if (rect.x0 != 0. || rect.y0 != 0) {
+			node = xmlNewDocNode (doc, NULL, (const xmlChar*)"g", NULL);
+			xmlAddChild (doc->children, node);
+			buf = g_strdup_printf ("translate(%g,%g)", - rect.x0, - rect.y0);
+			xmlNewProp (node, (const xmlChar*)"transform", (const xmlChar*)buf);
+			g_free (buf);
+		} else
+			node = doc->children;
+		g_printable_export_svg (G_PRINTABLE (m_pData->Group), doc, node);
+		setlocale (LC_NUMERIC, old_num_locale);
+		g_free (old_num_locale);
+		xmlIndentTreeOutput = true;
+		xmlKeepBlanksDefault (0);
+		xmlSaveFormatFile (filename, doc, true);
+		xmlFreeDoc (doc);
 	} else {
 		gnome_canvas_update_now (GNOME_CANVAS (m_pWidget));
 		GdkDrawable *drawable = GDK_DRAWABLE (gtk_widget_get_parent_window (m_pWidget));
@@ -825,3 +873,12 @@ void gcpView::ExportImage (const char* filename, const char* type)
 	}
 	m_pData->ShowSelection (true);
 }
+
+void gcpView::EnsureSize ()
+{
+	GnomeCanvas *canvas = GNOME_CANVAS (m_pWidget);
+	while (canvas->idle_id)
+		gtk_main_iteration();
+	gnome_canvas_update_now (canvas);
+	g_signal_emit_by_name (m_pWidget, "update_bounds");
+}
